@@ -5,4 +5,4 @@ Package that provides a testing API for some applications that are
 wrapped using LDTP library together with some test facilities to write
 automated test cases easily
 """
-__all__ = ['check', 'utils', 'application', 'test_suite']
+__all__ = ['check', 'utils', 'gconfwrapper', 'application', 'test_suite']
