@@ -38,7 +38,7 @@ class ResultDict(dict):
                                              strftime ("%m-%d-%Y-%H-%M-%s"))
         safe_make_directory(globals.SCREENSHOTS_SHARE)
         if not screenshot_file:
-            ldtputils.imagecapture(outFile = _logFile)
+            ldtputils.imagecapture(out_file = _logFile)
         else:
             move(screenshot_file, _logFile)
         self.append('screenshot', _logFile)
