@@ -5,6 +5,16 @@ execution
 import os, logging
 from stat import ST_MODE, S_IMODE
 from subprocess import Popen, PIPE
+from ..gconfwrapper import GConf
+
+def accessibility_enabled():
+    """
+    Check gconf key to determine if accessibility is enabled.
+    
+    @return: Value of accessibility key in gconf
+    @rtype: bool
+    """
+    return GConf.get_item('/desktop/gnome/interface/accessibility')
 
 def safe_change_mode(path, mode):
     """
